package webui

import (
    "fmt"
	"net/http"
    "gitea.armuli.eu/museum-digital/museum-digital-webdav-uploader/src/uploadsrcdir"
    "gitea.armuli.eu/museum-digital/museum-digital-webdav-uploader/src/webdavupload"
)

// Provides the API logic for uploading files.
func serveApiTriggerUpload(w http.ResponseWriter, r *http.Request) {

    fmt.Println("Upload requested")
	setHeadersForEventStream(w)
    w.(http.Flusher).Flush()

    fmt.Fprint(w, "Getting list of uploadable files\n")
    w.(http.Flusher).Flush()
    uploadableMetadata, uploadableMedia := uploadsrcdir.GetUploadableFiles(config)

    // If there are no files to upload, do nothing
    if len(uploadableMetadata) == 0 && len(uploadableMedia) == 0 {
        return
    }

    fmt.Fprint(w, "Connecting to WebDAV share\n")
    w.(http.Flusher).Flush()
    c := webdavupload.GetWebdavClient(config)
    fmt.Fprint(w, "Connected\n")
    w.(http.Flusher).Flush()

    if webdavupload.CheckRemoteIsFree(c) == false {
        fmt.Println("The remote is currently occupied (very recent files, or an import config is currently waiting to be processed, are present).")
        return
    }

    // Upload the files
    if len(uploadableMetadata) > 0 {
        fmt.Fprint(w, "Uploading metadata files\n")
        w.(http.Flusher).Flush()
        webdavupload.UploadMetadataFiles(c, w, uploadableMetadata)
        webdavupload.BatchUnlink(w, uploadableMetadata)
    }
    if len(uploadableMedia) > 0 {
        fmt.Fprint(w, "Uploading media files\n")
        webdavupload.UploadMediaFiles(c, w, uploadableMedia)
        webdavupload.BatchUnlink(w, uploadableMedia)
    }

    fmt.Fprint(w, "Generating and uploading import configuration\n")
    webdavupload.SetImportConfigToTheRemote(c, config)
    fmt.Fprint(w, "DONE\n")
    w.(http.Flusher).Flush()

}
